function varargout = gui_boolean03(varargin)
% GUI_BOOLEAN03 MATLAB code for gui_boolean03.fig
%      GUI_BOOLEAN03, by itself, creates a new GUI_BOOLEAN03 or raises the existing
%      singleton*.
%
%      H = GUI_BOOLEAN03 returns the handle to a new GUI_BOOLEAN03 or the handle to
%      the existing singleton*.
%
%      GUI_BOOLEAN03('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUI_BOOLEAN03.M with the given input arguments.
%
%      GUI_BOOLEAN03('Property','Value',...) creates a new GUI_BOOLEAN03 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gui_boolean03_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gui_boolean03_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help gui_boolean03

% Last Modified by GUIDE v2.5 26-Jan-2015 13:49:31

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_boolean03_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_boolean03_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gui_boolean03 is made visible.
function gui_boolean03_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui_boolean03 (see VARARGIN)

% Choose default command line output for gui_boolean03
handles.output = hObject;
set(gca,'xtick',[],'ytick',[])
handles.edit_expression = 'a&b&c';
%set(handles.edit_expression,'String',handles.edit_expression)
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_boolean03 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gui_boolean03_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit_expression_Callback(hObject, eventdata, handles)
% hObject    handle to edit_expression (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_expression as text
%        str2double(get(hObject,'String')) returns contents of edit_expression as a double
handles.edit_expression = get(hObject,'String');
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function edit_expression_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_expression (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in push_eval.
function push_eval_Callback(hObject, eventdata, handles)
% hObject    handle to push_eval (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[out] = logic_abcx(handles.edit_expression);
axes(handles.axes1)
%figure
plot(0,0)
%axes('PlotBoxAspectRatio',[2 4 2])
outd = double(out);
outa = num2str(outd);
header = 'a  b  c  f'
output = [header;outa];
text(-.9,0,output,'FontSize',24,'FontWeight','demi')
set(gca,'xtick',[],'ytick',[])
